@@ -368,7 +368,7 @@ def set_git_sha():
 @task
 def tar_from_git(branch, dirs=None, baseDir='.'):
     
-    with lwd(baseDir):
+    with lcd(baseDir):
         local("pwd")
         if dirs:
             local('tar -czf %s.tar.gz %s' % (TAR_NAME, dirs))
